Package: TSdist
Type: Package
Title: Distance Measures for Time Series Data
Version: 3.6
Encoding: UTF-8
Date: 2019-07-17
Depends: R (>= 3.0.3), proxy
Imports: zoo, xts, dtw, TSclust, KernSmooth, locpol, pdc,
        longitudinalData, cluster, methods, graphics, stats
Suggests: testthat
Authors@R: c(person("Usue", "Mori", email = "usue.mori@ehu.eus",role = c("aut", "cre")),person("Alexander", "Mendiburu", role = c("aut")),person("Jose A.", "Lozano", role = c("aut")),person("Duarte", "Folgado", role = c("ctb")))
Description: A set of commonly used distance measures and some additional functions which, although initially not designed for this purpose, can be used to measure the dissimilarity between time series. These measures can be used to perform clustering, classification or other data mining tasks which require the definition of a distance measure between time series.
License: GPL (>= 2)
Packaged: 2019-07-16 06:40:51 UTC; sgpmocau
NeedsCompilation: yes
Repository: CRAN
Author: Usue Mori [aut, cre],
  Alexander Mendiburu [aut],
  Jose A. Lozano [aut],
  Duarte Folgado [ctb]
Maintainer: Usue Mori <usue.mori@ehu.eus>
Date/Publication: 2019-07-18 11:18:36 UTC
Built: R 3.5.1; x86_64-w64-mingw32; 2019-08-08 14:41:55 UTC; windows
Archs: x64
