#Import proxy
importFrom(proxy,dist)
importFrom(proxy,pr_DB)

#Import zoo
import(zoo)

#Import zoo
import(cluster)

#Import KernSmooth
import(KernSmooth)

#Import locpol
import(locpol)

#Import xts
import(xts)

#Import distance measures from TSclust
import(TSclust)

#Import pdc
import(pdc)

#Import longitudinalData
import(longitudinalData)

#Import dtw
import(dtw)

#dtw, edr, erp, lcss core functions
useDynLib(TSdist, .registration = TRUE)

#Other global environments
importFrom("graphics", "legend", "lines", "plot.default")
importFrom("methods", "is")
importFrom("stats", "approx", "as.dist", "ccf", "dnorm", "fft", 
"integrate", "is.mts", "is.ts", "optim", "spec.pgram", "time")


#Export distance functions

export(CCorDistance, DissimDistance, DTWDistance, EDRDistance, ERPDistance, 
       LCSSDistance, FourierDistance,LBKeoghDistance, LPDistance,
       EuclideanDistance, ManhattanDistance, MinkowskiDistance, InfNormDistance,
       STSDistance, TquestDistance, ACFDistance, PACFDistance, 
       ARLPCCepsDistance, ARMahDistance, ARPicDistance, CDMDistance, 
       CIDDistance, CorDistance, CortDistance, WavDistance, IntPerDistance, 
       PerDistance, MindistSaxDistance, NCDDistance, PredDistance, 
       SpecGLKDistance, SpecISDDistance, SpecLLRDistance, FrechetDistance, 
       PDCDistance, TAMDistance)


#Export wrapper function for time series objects.
export(TSDistances)

#Export function to calculate distance matrices
export(TSDatabaseDistances)

#Export K-medoids function
export(KMedoids)

#Export 1NN function
export(OneNN)

